@@ -1376,9 +1376,9 @@ class FargateCluster(ECSCluster):
 
     **IAM Permissions**
 
-    To create a ``FargateCluster`` the cluster manager will need to various AWS resources ranging from IAM roles to
+    To create a ``FargateCluster`` the cluster manager will need to use various AWS resources ranging from IAM roles to
     VPCs to ECS tasks. Depending on your use case you may want the cluster to create all of these for you, or you
-    may wish to specify them youself ahead of time.
+    may wish to specify them yourself ahead of time.
 
     Here is the full minimal IAM policy that you need to create the whole cluster:
 
